@@ -1049,7 +1049,7 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
        if it has a child menu. */
     {
       gchar *type, *label, *tooltip, *icon_name, *accel_mods;
-      gchar *pixmap_type, *pixmap_info;
+      gchar *pixmap_type, *pixmap_info, *pixmap_filename;
       gchar accel_key_buffer[128];
       gboolean free_pixmap_info;
       
@@ -1066,7 +1066,7 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
 	  gint stock_icon_index;
 
 	  stock_icon_index = glade_gnome_get_stock_menu_pixmap_index (icon_name);
-	  if (stock_icon_index)
+	  if (stock_icon_index >= 0)
 	    {
 	      pixmap_type = "GNOME_APP_PIXMAP_STOCK";
 	      pixmap_info = (gchar*)GladeStockMenuPixmapSymbols[stock_icon_index];
@@ -1074,9 +1074,12 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
 	  else
 	    {
 	      pixmap_type = "GNOME_APP_PIXMAP_FILENAME";
-	      pixmap_info = g_strdup_printf ("%s%c%s", data->program_name,
-					     G_DIR_SEPARATOR,
-					     g_basename (icon_name));
+	      pixmap_filename = g_strdup_printf ("%s%c%s", data->program_name,
+						 G_DIR_SEPARATOR,
+						 g_basename (icon_name));
+	      pixmap_info = g_strdup (source_make_string (pixmap_filename,
+							  FALSE));
+	      g_free (pixmap_filename);
 	      free_pixmap_info = TRUE;
 	    }
 	}
@@ -1118,8 +1121,7 @@ glade_gnome_write_menu_item_source (GtkMenuItem * widget,
 							data->use_gettext),
 			     tooltip ? tooltip : "NULL",
 			     data->real_wname,
-			     pixmap_type,
-			     source_make_string (pixmap_info, FALSE),
+			     pixmap_type, pixmap_info,
 			     accel_key_buffer, accel_mods);
 	  
 	}
