@@ -18,7 +18,9 @@
 
 #include <string.h>
 #include <sys/stat.h>
+#ifndef _WIN32
 #include <unistd.h>
+#endif
 #include <errno.h>
 
 #include <gtk/gtkmenu.h>
@@ -1168,10 +1170,9 @@ glade_project_load_options (GladeProject *project,
 
   base = g_dirname (project->xml_filename);
 
-  /* Set some default options so that pre-0.5.0 projects still work. */
-  project->output_main_file = FALSE;
-  project->gnome_support = FALSE;
-  project->gettext_support = FALSE;
+  /* Set some default options, which are different from those set in new(). */
+  project->gnome_support = TRUE;
+  project->gettext_support = TRUE;
 
   for (;;)
     {
@@ -1318,7 +1319,7 @@ glade_project_load_options (GladeProject *project,
   if (project->directory == NULL)
     project->directory = g_strdup (base);
   if (project->source_directory == NULL)
-    project->source_directory = g_strdup (base);
+    project->source_directory = glade_util_make_absolute_path (base, "src");
   if (project->pixmaps_directory == NULL)
     project->pixmaps_directory = glade_util_make_absolute_path (base,
 								"pixmaps");
@@ -1341,33 +1342,63 @@ glade_project_save_options (GladeProject *project,
   /* All directories are saved relative to the xml file's directory. */
   base_dir = glade_util_dirname (project->xml_filename);
 
+  /* For now we will only use default values for C options which will not
+     affect Glade versions 0.5.0-0.5.5. */
+
   dir = glade_util_make_relative_path (base_dir, project->directory);
-  save_string (data, "directory", dir);
+  /*if (strcmp (dir, ""))*/
+    save_string (data, "directory", dir);
   g_free (dir);
 
   dir = glade_util_make_relative_path (base_dir, project->source_directory);
-  save_string (data, "source_directory", dir);
+  /*if (strcmp (dir, "src"))*/
+    save_string (data, "source_directory", dir);
   g_free (dir);
 
   dir = glade_util_make_relative_path (base_dir, project->pixmaps_directory);
-  save_string (data, "pixmaps_directory", dir);
+  /*if (strcmp (dir, "pixmaps"))*/
+    save_string (data, "pixmaps_directory", dir);
   g_free (dir);
 
-  save_string (data, "language", GladeLanguages[project->language]);
-  save_bool   (data, "gnome_support", project->gnome_support);
-  save_bool   (data, "gettext_support", project->gettext_support);
-  save_bool   (data, "use_widget_names", project->use_widget_names);
-  save_bool   (data, "output_main_file", project->output_main_file);
-  save_bool   (data, "output_support_files", project->output_support_files);
-  save_bool   (data, "output_build_files", project->output_build_files);
-  save_bool   (data, "backup_source_files", project->backup_source_files);
+  /*if (project->language != GLADE_LANGUAGE_C)*/
+    save_string (data, "language", GladeLanguages[project->language]);
+  /*if (!project->gnome_support)*/
+    save_bool   (data, "gnome_support", project->gnome_support);
 
-  save_string (data, "main_source_file", project->main_source_file);
-  save_string (data, "main_header_file", project->main_header_file);
-  save_string (data, "handler_source_file", project->handler_source_file);
-  save_string (data, "handler_header_file", project->handler_header_file);
-  save_string (data, "support_source_file", project->support_source_file);
-  save_string (data, "support_header_file", project->support_header_file);
+  /*
+   * C Options.
+   */
+  /*if (!project->gettext_support)*/
+    save_bool   (data, "gettext_support", project->gettext_support);
+  if (project->use_widget_names)
+    save_bool   (data, "use_widget_names", project->use_widget_names);
+  if (!project->output_main_file)
+    save_bool   (data, "output_main_file", project->output_main_file);
+  if (!project->output_support_files)
+    save_bool   (data, "output_support_files", project->output_support_files); 
+  if (!project->output_build_files)
+    save_bool   (data, "output_build_files", project->output_build_files);
+  if (!project->backup_source_files)
+    save_bool   (data, "backup_source_files", project->backup_source_files);
+
+  if (!project->main_source_file
+      || strcmp (project->main_source_file, "interface.c"))
+    save_string (data, "main_source_file", project->main_source_file);
+  if (!project->main_header_file
+      || strcmp (project->main_header_file, "interface.h"))
+    save_string (data, "main_header_file", project->main_header_file);
+  if (!project->handler_source_file
+      || strcmp (project->handler_source_file, "callbacks.c"))
+    save_string (data, "handler_source_file", project->handler_source_file);
+  if (!project->handler_header_file
+      || strcmp (project->handler_header_file, "callbacks.h"))
+    save_string (data, "handler_header_file", project->handler_header_file);
+  if (!project->support_source_file
+      || strcmp (project->support_source_file, "support.c"))
+    save_string (data, "support_source_file", project->support_source_file);
+  if (!project->support_header_file
+      || strcmp (project->support_header_file, "support.h"))
+    save_string (data, "support_header_file", project->support_header_file);
 
   if (project->output_translatable_strings)
     save_bool (data, "output_translatable_strings", TRUE);
@@ -1375,7 +1406,8 @@ glade_project_save_options (GladeProject *project,
       && project->translatable_strings_file[0])
     {
       file = glade_util_make_relative_path (base_dir, project->translatable_strings_file);
-      save_string (data, "translatable_strings_file", file);
+      if (strcmp (file, ""))
+	save_string (data, "translatable_strings_file", file);
       g_free (file);
     }
 
