@@ -141,6 +141,7 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_window_set_position (GTK_WINDOW (options), GTK_WIN_POS_MOUSE);
   gtk_window_set_title (GTK_WINDOW (options), _("Project Options"));
   gtk_window_set_policy (GTK_WINDOW (options), FALSE, TRUE, FALSE);
+  gtk_window_set_wmclass (GTK_WINDOW (options), "project_options", "Glade");
 
   main_vbox = gtk_vbox_new (FALSE, 4);
   gtk_container_add (GTK_CONTAINER (options), main_vbox);
@@ -1283,6 +1284,8 @@ glade_project_options_check_valid	(GladeProjectOptions *options)
   gchar *error = NULL;
   gchar *directory, *xml_filename, *project_name, *program_name;
   gchar *source_directory, *pixmaps_directory;
+  gboolean output_translatable_strings;
+  gchar *translatable_strings_filename;
 
   directory = get_entry_text (options->directory_entry);
   xml_filename = get_entry_text (options->xml_filename_entry);
@@ -1290,23 +1293,36 @@ glade_project_options_check_valid	(GladeProjectOptions *options)
   program_name = get_entry_text (options->program_name_entry);
   source_directory = get_entry_text (options->source_directory_entry);
   pixmaps_directory = get_entry_text (options->pixmaps_directory_entry);
+  output_translatable_strings = GTK_TOGGLE_BUTTON (options->output_translatable_strings)->active;
+  translatable_strings_filename = get_entry_text (options->translatable_strings_filename_entry);
 
   switch (options->action)
     {
     case GLADE_PROJECT_OPTIONS_ACTION_NORMAL:
-      /* Don't need anything set. */
+      if (output_translatable_strings
+	  && (translatable_strings_filename == NULL
+	      || translatable_strings_filename[0] == '\0'))
+	error = _("You need to set the Translatable Strings File option");
       break;
     case GLADE_PROJECT_OPTIONS_ACTION_SAVE:
       if (directory == NULL || directory[0] == '\0')
 	error = _("You need to set the Project Directory option");
       else if (xml_filename == NULL || xml_filename[0] == '\0')
 	error = _("You need to set the Project File option");
+      else if (output_translatable_strings
+	       && (translatable_strings_filename == NULL
+		   || translatable_strings_filename[0] == '\0'))
+	error = _("You need to set the Translatable Strings File option");
       break;
     case GLADE_PROJECT_OPTIONS_ACTION_BUILD:
       if (directory == NULL || directory[0] == '\0')
 	error = _("You need to set the Project Directory option");
       else if (xml_filename == NULL || xml_filename[0] == '\0')
 	error = _("You need to set the Project File option");
+      else if (output_translatable_strings
+	       && (translatable_strings_filename == NULL
+		   || translatable_strings_filename[0] == '\0'))
+	error = _("You need to set the Translatable Strings File option");
       else if (project_name == NULL || project_name[0] == '\0')
 	error = _("You need to set the Project Name option");
       else if (program_name == NULL || program_name[0] == '\0')
