@@ -60,6 +60,9 @@
 static gchar *GladeProjectWindowKey = "GladeProjectWindowKey";
 
 
+static gboolean glade_project_window_delete_event (GtkWidget *widget,
+						   GdkEvent *event,
+						   GladeProjectWindow *project_window);
 static void glade_project_window_destroy (GtkWidget *widget,
 					  gpointer   data);
 
@@ -100,6 +103,9 @@ static void glade_project_window_show_error (GladeProjectWindow *project_window,
 
 static void glade_project_window_quit (GtkWidget *widget,
 				       gpointer   data);
+static void glade_project_window_show_quit_dialog (GladeProjectWindow *project_window);
+static void glade_project_window_on_quit_ok (GtkWidget *button,
+					     GladeProjectWindow *project_window);
 
 static void glade_project_window_cut (GtkWidget *widget,
 				      gpointer   data);
@@ -332,6 +338,8 @@ glade_project_window_new (void)
 
   project_window->window = gnome_app_new ("Glade", "Glade");
   gtk_widget_set_name (project_window->window, "GladeProjectWindow");
+  gtk_window_set_wmclass (GTK_WINDOW (project_window->window),
+			  "project", "Glade");
 
   /* We want all the keyboard accelerators from the menus in the default
      accel_group (or they won't work within the interface windows), so we
@@ -347,6 +355,9 @@ glade_project_window_new (void)
 
   gtk_signal_connect (GTK_OBJECT (project_window->window), "destroy",
 		      GTK_SIGNAL_FUNC (glade_project_window_destroy), NULL);
+  gtk_signal_connect (GTK_OBJECT (project_window->window), "delete_event",
+		      GTK_SIGNAL_FUNC (glade_project_window_delete_event),
+		      project_window);
   gtk_signal_connect_after (GTK_OBJECT (project_window->window),
 			    "key_press_event",
 			    GTK_SIGNAL_FUNC (glade_project_window_key_press_event),
@@ -413,6 +424,8 @@ glade_project_window_new (void)
   project_window->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_widget_set_name (project_window->window, "GladeProjectWindow");
   gtk_window_set_title (GTK_WINDOW (project_window->window), "Glade");
+  gtk_window_set_wmclass (GTK_WINDOW (project_window->window),
+			  "project", "Glade");
 
   /* Save a pointer to the GladeProjectWindow, so we can find it in callbacks.
    */
@@ -423,6 +436,9 @@ glade_project_window_new (void)
 
   gtk_signal_connect (GTK_OBJECT (project_window->window), "destroy",
 		      GTK_SIGNAL_FUNC (glade_project_window_destroy), NULL);
+  gtk_signal_connect (GTK_OBJECT (project_window->window), "delete_event",
+		      GTK_SIGNAL_FUNC (glade_project_window_delete_event),
+		      project_window);
   gtk_signal_connect_after (GTK_OBJECT (project_window->window),
 			    "key_press_event",
 			    GTK_SIGNAL_FUNC (glade_project_window_key_press_event),
@@ -780,6 +796,16 @@ get_glade_project_window (GtkWidget *widget)
 }
 
 
+static gboolean
+glade_project_window_delete_event (GtkWidget *widget,
+				   GdkEvent *event,
+				   GladeProjectWindow *project_window)
+{
+  glade_project_window_show_quit_dialog (project_window);
+  return TRUE;
+}
+
+
 static void
 glade_project_window_destroy (GtkWidget *widget,
 			      gpointer   data)
@@ -811,6 +837,7 @@ glade_project_window_new_project (GtkWidget *widget,
 
   dialog = glade_util_create_dialog_with_buttons (_("Are you sure you want to create a new project?"), 2, buttons, 2, handlers, project_window);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+  gtk_window_set_wmclass (GTK_WINDOW (dialog), "new_project", "Glade");
   gtk_window_set_transient_for (GTK_WINDOW (dialog),
 				GTK_WINDOW (project_window->window));
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
@@ -846,6 +873,7 @@ glade_project_window_on_open_project (GtkWidget *widget,
 
   filesel = gtk_file_selection_new (_("Open Project"));
   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
+  gtk_window_set_wmclass (GTK_WINDOW (filesel), "open_project", "Glade");  
   if (project_window->current_directory)
     gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel),
 				     project_window->current_directory);
@@ -923,6 +951,7 @@ glade_project_window_show_loading_errors (GladeProjectWindow *project_window,
   dialog = glade_project_window_new_errors_dialog (project_window, &text);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Errors opening project file"));
+  gtk_window_set_wmclass (GTK_WINDOW (dialog), "error", "Glade");
 
   gtk_text_freeze (GTK_TEXT (text));
   sprintf (buf, "\n%i", g_list_length (errors));
@@ -1272,6 +1301,7 @@ glade_project_window_show_error (GladeProjectWindow *project_window,
   dialog = glade_project_window_new_errors_dialog (project_window, &text);
 
   gtk_window_set_title (GTK_WINDOW (dialog), title);
+  gtk_window_set_wmclass (GTK_WINDOW (dialog), "error", "Glade");
 
   gtk_text_freeze (GTK_TEXT (text));
 
@@ -1311,6 +1341,30 @@ glade_project_window_quit (GtkWidget *widget,
   project_window = get_glade_project_window (widget);
   g_return_if_fail (project_window != NULL);
 
+  glade_project_window_show_quit_dialog (project_window);
+}
+
+
+static void
+glade_project_window_show_quit_dialog (GladeProjectWindow *project_window)
+{
+  GtkWidget *dialog;
+  const gchar *buttons[] = { N_("Yes"), N_("No") };
+  GtkSignalFunc handlers[] = { glade_project_window_on_quit_ok, NULL };
+
+  dialog = glade_util_create_dialog_with_buttons (_("Are you sure you want to quit?"), 2, buttons, 2, handlers, project_window);
+  gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+  gtk_window_set_transient_for (GTK_WINDOW (dialog),
+				GTK_WINDOW (project_window->window));
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  gtk_widget_show (dialog);
+}
+
+
+static void
+glade_project_window_on_quit_ok (GtkWidget *button,
+				 GladeProjectWindow *project_window)
+{
   gtk_widget_destroy (project_window->window);
 }
 
@@ -1498,6 +1552,7 @@ glade_project_window_about (GtkWidget *widget,
 			   "Web: http://glade.pn.org\n",
 			   PACKAGE G_DIR_SEPARATOR_S "glade_logo.png");
   gtk_window_set_modal (GTK_WINDOW (about), TRUE);
+  gtk_window_set_wmclass (GTK_WINDOW (about), "about", "Glade");
   gtk_widget_show (about);
 #else
   message = g_strdup_printf (_("G L A D E\n\n"
