@@ -21,7 +21,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stdarg.h>
+#ifndef _WIN32
 #include <unistd.h>
+#endif
 #include <errno.h>
 #include <ctype.h>
 #include <locale.h>
@@ -118,6 +120,7 @@ static void source_write_check_file_exists_function (GbWidgetWriteSourceData * d
 static void source_write_gnome_create_pixmap_functions (GbWidgetWriteSourceData * data,
 							FILE *fp);
 
+static gchar* source_is_valid_source_filename (const gchar * filename);
 static GladeError* source_backup_file_if_exists (const gchar * filename);
 
 static gchar * source_make_string_internal (const gchar * text,
@@ -159,7 +162,8 @@ source_write_internal (GladeProject * project)
 {
   GbWidgetWriteSourceData data;
   gchar *source_directory, *interface_source_file, *interface_header_file;
-  gchar *callback_source_file, *callback_header_file;
+  gchar *callback_source_file, *callback_header_file, *msg;
+  gchar *support_source_file, *support_header_file;
   gint i;
 
   source_directory = glade_project_get_source_directory (project);
@@ -169,6 +173,26 @@ source_write_internal (GladeProject * project)
 				  &callback_source_file,
 				  &callback_header_file);
 
+  /* Check that any source filenames that we are going to use are valid. */
+  if ((msg = source_is_valid_source_filename (interface_source_file)))
+    return glade_error_new_general (GLADE_STATUS_ERROR, _("Invalid interface source filename: %s\n%s\n"), interface_source_file, msg);
+  if ((msg = source_is_valid_source_filename (interface_header_file)))
+    return glade_error_new_general (GLADE_STATUS_ERROR, _("Invalid interface header filename: %s\n%s\n"), interface_header_file, msg);
+
+  if ((msg = source_is_valid_source_filename (callback_source_file)))
+    return glade_error_new_general (GLADE_STATUS_ERROR, _("Invalid callbacks source filename: %s\n%s\n"), callback_source_file, msg);
+  if ((msg = source_is_valid_source_filename (callback_header_file)))
+    return glade_error_new_general (GLADE_STATUS_ERROR, _("Invalid callbacks header filename: %s\n%s\n"), callback_source_file, msg);
+
+  if (glade_project_get_output_support_files (project)) {
+    support_source_file = glade_project_get_support_source_file (project);
+    support_header_file = glade_project_get_support_header_file (project);
+    if ((msg = source_is_valid_source_filename (support_source_file)))
+      return glade_error_new_general (GLADE_STATUS_ERROR, _("Invalid support source filename: %s\n%s\n"), support_source_file, msg);
+    if ((msg = source_is_valid_source_filename (support_header_file)))
+      return glade_error_new_general (GLADE_STATUS_ERROR, _("Invalid support header filename: %s\n%s\n"), support_header_file, msg);
+  }
+
   /* Initialize the GbWidgetWriteSourceData fields.
      Note that the error is set to NULL. If anything sets it we know there is
      an error. */
@@ -944,9 +968,11 @@ source_write_gtk_autogen_sh (GbWidgetWriteSourceData * data)
     }
 
   /* We need to make the script executable, but we try to honour any umask. */
+#ifndef _WIN32
   old_umask = umask (0666);
   chmod (destbuffer, 0777 & ~old_umask);
   umask (old_umask);
+#endif
 
   g_free (srcbuffer);
   g_free (destbuffer);
@@ -1306,10 +1332,12 @@ source_write_gnome_autogen_sh (GbWidgetWriteSourceData * data)
 
   fclose (fp);
 
+#ifndef _WIN32
   /* We need to make the script executable, but we try to honour any umask. */
   old_umask = umask (0666);
   chmod (filename, 0777 & ~old_umask);
   umask (old_umask);
+#endif
 
   g_free (filename);
 }
@@ -1585,7 +1613,7 @@ source_write_gnome_macro_files (GbWidgetWriteSourceData * data)
     "gnome-common.m4",
     /*"gnome-cxx-check.m4",*/
     "gnome-fileutils.m4",
-    "gnome-gettext.m4",
+    /*"gnome-gettext.m4",*/
     "gnome-ghttp-check.m4",
     "gnome-gnorba-check.m4",
     "gnome-guile-checks.m4",
@@ -2520,11 +2548,14 @@ source_ensure_decl	(GbWidgetWriteSourceData *data,
 gchar *
 source_create_valid_identifier (const gchar * name)
 {
-  gint name_len, i;
+  gint name_len, i, j;
   gchar *identifier;
 
   name_len = strlen (name);
-  identifier = g_malloc (name_len + 1);
+  /* allocate extra space for _ prefix if the identifier starts with
+     a number */
+  identifier = g_malloc (name_len + 2);
+  j = 1;
 
   /* The first character of an identifier must be in [a-zA-Z_] */
   if ((name[0] >= 'a' && name[0] <= 'z')
@@ -2532,21 +2563,32 @@ source_create_valid_identifier (const gchar * name)
       || name[0] == '_')
     identifier[0] = name[0];
   else
-    identifier[0] = '_';
+    {
+      if (name[0] >= '0' && name[0] <= '9')
+	{
+	  /* prepend the _ instead of overwriting, so you'll still have
+	     unique names */
+	  identifier[0] = '_';
+	  identifier[1] = name[0];
+	  j++;
+	}
+      else
+	identifier[0] = '_';
+    }
 
   /* The remaining characters must be in [a-zA-Z0-9_] */
-  for (i = 1; i < name_len; i++)
+  for (i = 1; i < name_len; i++, j++)
     {
       if ((name[i] >= 'a' && name[i] <= 'z')
 	  || (name[i] >= 'A' && name[i] <= 'Z')
 	  || (name[i] >= '0' && name[i] <= '9')
 	  || name[i] == '_')
-	identifier[i] = name[i];
+	identifier[j] = name[i];
       else
-	identifier[i] = '_';
+	identifier[j] = '_';
     }
 
-  identifier[name_len] = '\0';
+  identifier[j] = '\0';
 
   return identifier;
 }
@@ -2721,6 +2763,22 @@ source_free_hash_keys_callback (gchar * key, gpointer value, gpointer data)
 }
 
 
+/* Checks if the given file is a valid source filename, i.e. not NULL and
+   not absolute. If not it returns an appropriate error message. */
+static gchar*
+source_is_valid_source_filename (const gchar * filename)
+{
+  if (filename == NULL || filename[0] == '\0')
+    return _("The filename must be set in the Project Options dialog.");
+
+  if (g_path_is_absolute (filename))
+    return _("The filename must be a simple relative filename.\n"
+	     "Use the Project Options dialog to set it.");
+
+  return NULL;
+}
+
+
 /* Checks if the given file exists, and if so renames it to file.bak. */
 static GladeError*
 source_backup_file_if_exists (const gchar * filename)
