@@ -19,8 +19,13 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef _WIN32
+#include <ctype.h>
+#include <direct.h>
+#else
 #include <unistd.h>
 #include <dirent.h>
+#endif
 #include <errno.h>
 
 #include <gtk/gtk.h>
@@ -577,6 +582,24 @@ glade_util_create_pixmap_using_colormap (GdkColormap  *colormap,
 }
 
 
+/* This returns TRUE if the widget is a toplevel project component,
+   i.e. a window, dialog or popup menu. */
+gboolean
+glade_util_is_component	(GtkWidget	   *widget)
+{
+  if (widget->parent == NULL)
+    return TRUE;
+
+  /* Note that menus may have submenus, so we make sure that this is the
+     toplevel menu. */
+  if (GTK_IS_MENU (widget)
+      && gtk_menu_get_attach_widget (GTK_MENU (widget)) == NULL)
+    return TRUE;
+
+  return FALSE;
+}
+
+
 /* This returns the toplevel window/dialog/menu that contains the given
    widget. It even walks up menus, which gtk_widget_get_toplevel() does not. */
 GtkWidget*
@@ -1248,7 +1271,11 @@ glade_util_ensure_directory_exists (const gchar *directory)
 	  if (error)
 	    return error;
 
+#ifdef _WIN32
+	  if (mkdir (directory) != 0)
+#else
 	  if (mkdir (directory, 0777) != 0)
+#endif
 	    {
 	      return glade_error_new_system (_("Couldn't create directory:\n  %s\n"), directory);
 	    }
@@ -1258,6 +1285,7 @@ glade_util_ensure_directory_exists (const gchar *directory)
 	  return glade_error_new_system (_("Couldn't access directory:\n  %s\n"), directory);
 	}
     }
+#ifndef _WIN32
   /* If the directory does exist, check it is a directory. */
   else if (!S_ISDIR (filestat.st_mode))
     {
@@ -1265,6 +1293,7 @@ glade_util_ensure_directory_exists (const gchar *directory)
 				      _("Invalid directory:\n  %s\n"),
 				      directory);
     }
+#endif
 
   return NULL;
 }
